@@ -274,9 +274,7 @@ use Exporter qw(import);
 use Carp qw(croak carp confess cluck);
 use Scalar::Util qw(blessed reftype refaddr weaken isweak);
 
-our @EXPORT_OK = qw(factory register_special_classes);
-
-our %special_classes = (Regexp => undef);
+our @EXPORT_OK = qw(factory);
 
 sub seen { shift->{seen} //= {} }
 sub weak { shift->{weak} //= {} }
@@ -297,10 +295,6 @@ sub id {
 	return "\$$name" . ++$self->{id}{$name};
 }
 
-sub register_special_classes {
-	@special_classes{@_} = ();
-}
-
 sub register_leaf {
 	my $self = shift;
 	my $case = shift;
@@ -545,13 +539,7 @@ sub codegen_force {
 	if(ref $case) {
 		my $codegen = 'codegen_' . reftype $case;
 		return $self->register_leaf($case)
-			unless $self->can($codegen);
-		if(my $class = blessed $case) {
-			return $self->register_leaf($case)
-				if exists $special_classes{$class};
-			my $n = $self->register_leaf($class);
-			return 'bless(', $self->$codegen($case, 1), ", $n)";
-		}
+			if blessed($case) || !$self->can($codegen);
 		return $self->$codegen($case);
 	} elsif($mutable || defined $case) {
 		return $self->register_leaf($case);
@@ -889,19 +877,12 @@ is still uninitialized it is allowed to set it once.
 
 =head3 Default values
 
-Clarity supports using default values of arbitrary complexity. It tries
-fairly hard to efficiently perform a deep copy (by precompiling a generator
-function). Some objects are uncopyable however, in particular XS wrappers
-and regular expressions. For this reason you can declare that some classes
-should be copied only shallowly:
+Clarity supports default values of arbitrary complexity. It tries fairly
+hard to efficiently perform a deep copy (by precompiling a generator
+function).
 
-=head4 Clarity::register_special_classes($classname ...)
-
-Objects from a class registered with this function will be copied by
-reference, instead of the usual deep copy.
-
- # do not attempt a deep copy of XML::LibXML::Document objects
- Clarity::register_special_classes('XML::LibXML::Document');
+Some objects are uncopyable however, in particular XS wrappers and regular
+expressions. For this reason blessed references are copied only shallowly.
 
 =head3 Automatic accessors
 
@@ -923,7 +904,7 @@ your fields in your new() method.
 It also allows you to create Clarity instances directly, useful if all
 you want to do is store some data.
 
- my $c = new Clarity(volume => 11, loud => 1);
+ my $c = new Clarity(volume => 11);
  print $c->volume;                      # prints '11'
 
 =head2 Automatic $self 
